@@ -6,11 +6,13 @@ import http.cookiejar
 import json
 import logging
 import os
+import random
 import shutil
 import subprocess
 import time
 import urllib
-import random
+
+import aiohttp
 
 _loggerName = 'beniutils'
 
@@ -294,7 +296,7 @@ def bExecuteWinScp(winscpExe, winscpKeyFile, server, commandAry):
 
 
 def bZipFile(toFile, fileFolderOrAry, rename=None):
-    from zipfile import ZipFile, ZIP_DEFLATED
+    from zipfile import ZIP_DEFLATED, ZipFile
     bMakeFolder(os.path.dirname(toFile))
     ary = fileFolderOrAry
     if type(ary) != list:
@@ -370,10 +372,10 @@ def bSyncFolder(fromFolder, toFolder):
 def bSendMail(host, password, fromMail, toMailList, subject, content='', attachmentList=None):
     '''发送邮件 attachmentList格式为[(name, bytes), ...]'''
 
+    import smtplib
     from email.header import Header
     from email.mime.multipart import MIMEMultipart
     from email.mime.text import MIMEText
-    import smtplib
 
     message = MIMEMultipart()
     message['From'] = fromMail
@@ -621,9 +623,7 @@ def bSetAsyncHttpMaxNum(value):
 
 
 async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
-    if isImportAioHttp:
-        import aiohttp
-        importAioHttp()
+    importAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
     result = None
@@ -636,7 +636,7 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
         currentTry += 1
         try:
             response = None
-            async with eval("aiohttp").ClientSession() as session:
+            async with aiohttp.ClientSession() as session:
                 response = await session.get(
                     url,
                     headers=headers,
@@ -657,9 +657,7 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
 
 
 async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
-    if isImportAioHttp:
-        import aiohttp
-        importAioHttp()
+    importAioHttp()
     global _currentAsyncHttpNum
     headers = _getHeaderByDefault(headers)
     result = None
@@ -672,7 +670,7 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
         currentTry += 1
         try:
             response = None
-            async with eval("aiohttp").ClientSession() as session:
+            async with aiohttp.ClientSession() as session:
                 response = await session.post(
                     url,
                     data=data,
@@ -699,11 +697,13 @@ isImportAioHttp = True
 def importAioHttp():
 
     global isImportAioHttp
+    if isImportAioHttp:
+        isImportAioHttp = False
+    else:
+        return
 
-    isImportAioHttp = False
-
-    from functools import wraps
     from asyncio.proactor_events import _ProactorBasePipeTransport
+    from functools import wraps
 
     # 尝试优化报错：RuntimeError: Event loop is closed
 
